@@ -131,11 +131,19 @@ get_full_path (GtkWidget *file_sel)
 	GtkWidget   *opt_menu;
 	char        *full_path;
 	const char  *path;
+	const char  *filename;
 	int          file_type_idx;
 
 	opt_menu = g_object_get_data (G_OBJECT (file_sel), "fr_opt_menu");
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_sel));
 
+	if ((path == NULL) || (*path == 0))
+		return NULL;
+
+	filename = file_name_from_path (path);
+	if ((filename == NULL) || (*filename == 0))
+		return NULL;
+	
 	file_type_idx = opt_menu_get_active_idx (opt_menu);
 	if (file_type_idx > 0) 
 		full_path = g_strconcat (path, 
@@ -159,9 +167,22 @@ new_file_ok_cb (GtkWidget *w,
 	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 
 	path = get_full_path (file_sel);
-        if (path == NULL) {
-		gtk_widget_destroy (file_sel);
-                return;
+
+	if ((path == NULL) || (*path == 0)) {
+		GtkWidget *dialog;
+
+		g_free (path);
+
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (file_sel),
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not create the archive"),
+						  _("You have to specify an archive name."),
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+		return;
 	}
 	
 	dir = remove_level_from_path (path);
@@ -171,11 +192,14 @@ new_file_ok_cb (GtkWidget *w,
 		g_free (dir);
 		g_free (path);
 
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("You don't have permission to create an archive in this folder"));
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (file_sel),
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not create the archive"),
+						  _("You don't have permission to create an archive in this folder"),
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
+
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		return;
@@ -198,10 +222,11 @@ new_file_ok_cb (GtkWidget *w,
 		GtkWidget *dialog;
 		int        r;
 
-		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (file_sel),
 						  GTK_DIALOG_MODAL,
 						  GTK_STOCK_DIALOG_QUESTION,
-						  _("Archive already exists.  Do you want to overwrite it?"),
+						  _("The archive already exists.  Do you want to overwrite it?"),
+						  NULL,
 						  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						  _("Overwrite"), GTK_RESPONSE_YES,
 						  NULL);
@@ -216,11 +241,13 @@ new_file_ok_cb (GtkWidget *w,
 
 		if (unlink (path) != 0) {
 			GtkWidget *dialog;
-			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 _("Could not delete old archive."));
+			dialog = _gtk_message_dialog_new (GTK_WINDOW (file_sel),
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_STOCK_DIALOG_ERROR,
+							  _("Could not delete the old archive."),
+							  NULL,
+							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (GTK_WIDGET (dialog));
 			return;
@@ -257,6 +284,7 @@ new_archive_cb (GtkWidget *widget,
 	FRWindow  *window = data;
 	GtkWidget *file_sel;
 	GtkWidget *hbox;
+	GtkWidget *vbox, *vbox2;
 	GtkWidget *opt_menu;
 	GtkWidget *menu;
 	char      *dir;
@@ -267,10 +295,16 @@ new_archive_cb (GtkWidget *widget,
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
 	g_free (dir);
 
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (file_sel)->action_area), vbox, TRUE, TRUE, 0);
+
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), vbox2, TRUE, TRUE, 6);
+
 	/**/
 
 	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (file_sel)->action_area), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, TRUE, 0);
 
 	gtk_box_pack_start (GTK_BOX (hbox), 
 			    gtk_label_new (_("Archive type:")),
@@ -328,9 +362,22 @@ save_file_ok_cb (GtkWidget *w,
 	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 
 	path = get_full_path (file_sel);
-        if (path == NULL) {
-		gtk_widget_destroy (file_sel);
-                return;
+
+	if ((path == NULL) || (*path == 0)) {
+		GtkWidget *dialog;
+
+		g_free (path);
+
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not save the archive"),
+						  _("You have to specify an archive name."),
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+		return;
 	}
 	
 	dir = remove_level_from_path (path);
@@ -340,11 +387,13 @@ save_file_ok_cb (GtkWidget *w,
 		g_free (dir);
 		g_free (path);
 
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("You don't have permission to create an archive in this folder"));
+		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+						  GTK_DIALOG_DESTROY_WITH_PARENT,
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not save the archive"),
+						  _("You don't have permission to create an archive in this folder"),
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		return;
@@ -362,7 +411,8 @@ save_file_ok_cb (GtkWidget *w,
 		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 						  GTK_DIALOG_MODAL,
 						  GTK_STOCK_DIALOG_QUESTION,
-						  _("Archive already exists.  Do you want to overwrite it?"),
+						  _("The archive already exists.  Do you want to overwrite it?"),
+						  NULL,
 						  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						  _("Overwrite"), GTK_RESPONSE_YES,
 						  NULL);
@@ -377,11 +427,13 @@ save_file_ok_cb (GtkWidget *w,
 
 		if (unlink (path) != 0) {
 			GtkWidget *dialog;
-			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 _("Could not delete old archive."));
+			dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_STOCK_DIALOG_ERROR,
+							  _("Could not delete the old archive."),
+							  NULL,
+							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (GTK_WIDGET (dialog));
 			return;
@@ -465,8 +517,8 @@ static void
 open_file_ok_cb (GtkWidget *w,
                  GtkWidget *file_sel)
 {
-	FRWindow *window;
-	const gchar *path;
+	FRWindow   *window;
+	const char *path;
 
 	window = g_object_get_data (G_OBJECT (file_sel), "fr_window");
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_sel));
@@ -474,9 +526,8 @@ open_file_ok_cb (GtkWidget *w,
         if (path == NULL)
                 return;
 
-	window_archive_open (window, path);
-
-	gtk_widget_destroy (file_sel);
+	if (window_archive_open (window, path, GTK_WINDOW (file_sel)))
+		gtk_widget_destroy (file_sel);
 }
 
 
@@ -485,8 +536,8 @@ open_archive_cb (GtkWidget *widget,
 		 void      *data)
 {
 	GtkWidget *file_sel;
-	FRWindow *window = data;
-	gchar *dir;
+	FRWindow  *window = data;
+	char      *dir;
 
         file_sel = gtk_file_selection_new (_("Open Archive"));
 
@@ -494,6 +545,8 @@ open_archive_cb (GtkWidget *widget,
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
 	g_free (dir);
 
+	/**/
+
 	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
 	
 	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
@@ -511,7 +564,7 @@ open_archive_cb (GtkWidget *widget,
 			  G_CALLBACK (open_file_destroy_cb),
 			  file_sel);
 
-	gtk_window_set_modal (GTK_WINDOW (file_sel),TRUE);
+	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	gtk_widget_show (file_sel);
 }
 
@@ -544,36 +597,41 @@ file_sel_destroy_cb (GtkWidget    *w,
 
 
 static void 
-copy_archive_ok_cb (GtkWidget    *w,
-		    CopyMoveData *data)
+copy_or_move_archive_ok_cb (GtkWidget    *w,
+			    CopyMoveData *data)
 {
-	FRWindow   *window;
-	const char *path;
-	char       *new_filename;
+	FRWindow    *window;
+	const char  *path;
+	const char  *filename;
+	char        *folder;
+	char        *new_path;
 
 	gtk_widget_hide (data->file_sel);
 
 	window = data->window;
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (data->file_sel));
 
-	if (path == NULL) {
+	if ((path == NULL) || (*path == 0)) {
                 gtk_widget_destroy (data->file_sel);
 		return;
 	}
 
-	if (path[strlen (path) - 1] == '/')
-		new_filename = g_strconcat (path, file_name_from_path (window->archive_filename), NULL);
-	else
-		new_filename = g_strconcat (path, "/", file_name_from_path (window->archive_filename), NULL);
+	filename = file_name_from_path (path);
+	if ((filename == NULL) || (*filename == 0))
+		filename = file_name_from_path (window->archive_filename);
+	folder = remove_level_from_path (path);
+	new_path = g_build_filename (folder, filename, NULL);
+	g_free (folder);
 
-	if (path_is_file (new_filename)) {
+	if (path_is_file (new_path)) {
 		GtkWidget *d;
 		int        r;
 
 		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 					     GTK_DIALOG_MODAL,
 					     GTK_STOCK_DIALOG_QUESTION,
-					     _("Archive already exists.  Do you want to overwrite it?"),
+					     _("The archive already exists.  Do you want to overwrite it?"),
+					     NULL,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     _("Overwrite"), GTK_RESPONSE_YES,
 					     NULL);
@@ -582,7 +640,7 @@ copy_archive_ok_cb (GtkWidget    *w,
 		gtk_widget_destroy (GTK_WIDGET (d));
 		
 		if (r != GTK_RESPONSE_YES) {
-			g_free (new_filename);
+			g_free (new_path);
 			gtk_widget_destroy (data->file_sel);
 			return;
 		}
@@ -590,37 +648,41 @@ copy_archive_ok_cb (GtkWidget    *w,
 	
 	if (data->copy) {
 #ifdef DEBUG
-		g_print ("cp %s %s\n", window->archive_filename, new_filename);
+		g_print ("cp %s %s\n", window->archive_filename, new_path);
 #endif
-		if (! file_copy (window->archive_filename, new_filename)) {
+		if (! file_copy (window->archive_filename, new_path)) {
 			GtkWidget *dialog;
-			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 _("Could not copy archive"));
+			dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_STOCK_DIALOG_ERROR,
+							  _("Could not copy the archive"),
+							  NULL,
+							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 		}
 	} else {
 #ifdef DEBUG
-		g_print ("mv %s %s\n", window->archive_filename, new_filename);
+		g_print ("mv %s %s\n", window->archive_filename, new_path);
 #endif
-		if (file_move (window->archive_filename, new_filename)) 
-			window_archive_rename (window, new_filename);
+		if (file_move (window->archive_filename, new_path)) 
+			window_archive_rename (window, new_path);
 		else {
 			GtkWidget *dialog;
-			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE,
-							 _("Could not move archive"));
+			dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+							  GTK_DIALOG_DESTROY_WITH_PARENT,
+							  GTK_STOCK_DIALOG_ERROR,
+							  _("Could not move the archive"),
+							  NULL,
+							  GTK_STOCK_OK, GTK_RESPONSE_OK,
+							  NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 		}
 	}
 
-	g_free (new_filename);
+	g_free (new_path);
 	gtk_widget_destroy (data->file_sel);
 }
 
@@ -638,7 +700,7 @@ copy_or_move_archive (FRWindow *window,
 	data->window = window;
 	data->copy = copy;
 	data->overwrite = overwrite;
-	data->file_sel = file_sel = gtk_file_selection_new (copy ? _("Copy archive") : _("Move archive"));
+	data->file_sel = file_sel = gtk_file_selection_new (copy ? _("Copy Archive") : _("Move Archive"));
 
 	dir = g_strconcat (window->open_default_dir, "/", NULL);
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_sel), dir);
@@ -649,7 +711,7 @@ copy_or_move_archive (FRWindow *window,
 
 	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
 			  "clicked", 
-			  G_CALLBACK (copy_archive_ok_cb), 
+			  G_CALLBACK (copy_or_move_archive_ok_cb), 
 			  data);
 
 	g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (file_sel)->cancel_button),
@@ -716,6 +778,7 @@ rename_archive_cb (GtkWidget *widget,
 	utf8_string = _gtk_request_dialog_run (GTK_WINDOW (window->app),
 					       (GTK_DIALOG_DESTROY_WITH_PARENT 
 						| GTK_DIALOG_MODAL),
+					       _("Rename Archive"),
 					       _("New archive name (without extension)"),
 					       utf8_old_string,
 					       1024,
@@ -745,7 +808,8 @@ rename_archive_cb (GtkWidget *widget,
 		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 					     GTK_DIALOG_MODAL,
 					     GTK_STOCK_DIALOG_QUESTION,
-					     _("Archive already exists.  Do you want to overwrite it?"),
+					     _("The archive already exists.  Do you want to overwrite it?"),
+					     NULL,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     _("Overwrite"), GTK_RESPONSE_YES,
 					     NULL);
@@ -830,7 +894,7 @@ delete_archive_cb (GtkWidget *widget,
 		d = _gtk_yesno_dialog_new (GTK_WINDOW (window->app),
 					   GTK_DIALOG_MODAL,
 					   _("The archive cannot be moved to the Trash. Do you want to delete it permanently?"),
-					   GTK_STOCK_CANCEL,
+					   GTK_STOCK_NO,
 					   GTK_STOCK_DELETE);
 		
 		r = gtk_dialog_run (GTK_DIALOG (d));
@@ -965,11 +1029,13 @@ manual_cb (GtkWidget *widget,
         if (err != NULL) {
                 GtkWidget *dialog;
                 
-                dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
-                                                 GTK_DIALOG_DESTROY_WITH_PARENT,                                                 GTK_MESSAGE_ERROR,
-                                                 GTK_BUTTONS_CLOSE,
-                                                 _("Could not display help: %s"),
-                                                 err->message);
+                dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
+						  GTK_DIALOG_DESTROY_WITH_PARENT, 
+						  GTK_STOCK_DIALOG_ERROR,
+						  _("Could not display help"),
+						  err->message,
+						  GTK_STOCK_OK, GTK_RESPONSE_OK,
+						  NULL);
                 
                 g_signal_connect (G_OBJECT (dialog), "response",
                                   G_CALLBACK (gtk_widget_destroy),
@@ -995,7 +1061,9 @@ about_cb (GtkWidget *widget,
 		"Paolo Bacchilega <paolo.bacch@tin.it>", NULL
 	};
 	const char       *documenters [] = {
-		"Alexander Kirillov", NULL
+		"Alexander Kirillov", 
+		"Breda McColgan",
+		NULL
 	};
 	const char       *translator_credits = _("translator_credits");
 
